import { Component, CUSTOM_ELEMENTS_SCHEMA, OnInit } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { Router } from '@angular/router';
import { AlertController, IonSegment, IonCard, IonCardTitle, IonCardSubtitle, IonButton, IonGrid, IonRow, IonToolbar, IonTitle } from '@ionic/angular/standalone';
import { IonSegmentButton, IonCardHeader, IonCardContent, IonCol, IonIcon, IonChip, IonHeader, IonContent } from '@ionic/angular/standalone';

@Component({
  selector: 'app-tab1',
  standalone: true,
  templateUrl: 'tab1.page.html',
  styleUrls: ['tab1.page.scss'],
  imports: [
    CommonModule,
    FormsModule,
    IonSegment,IonSegmentButton,IonCard,IonCardHeader,
    IonCardTitle,IonCardSubtitle,IonCardContent,IonButton,
    IonGrid,IonRow,IonCol,IonIcon,IonChip,
    IonHeader,IonContent,IonToolbar,IonTitle
  ],
  schemas: [CUSTOM_ELEMENTS_SCHEMA]
})
export class Tab1Page implements OnInit {
  // 为幻灯片设置默认的当前索引
  currentSlide: number = 0;

  // 图片列表
  images = [
    'assets/1.png',
    'assets/2.png',
    'assets/3.png'
  ];

  // 其他数据
  selectedTab: string = 'fitnessTips';

  fitnessTips = [
    { title: '如何正确热身', subtitle: '热身的重要性', description: '热身可以有效预防运动损伤，提升运动表现。' },
    { title: '力量训练的基础', subtitle: '增强肌肉力量', description: '力量训练是健身的重要组成部分，有助于提高基础代谢率。' },
  ];

  sportsNews = [
    { title: '2024年奥运会即将来临', date: '2024-12-15', description: '各国运动员正在积极备战，期待精彩赛事。' },
    { title: 'NBA新赛季开幕', date: '2024-10-01', description: '各大球队已做好准备，争夺总冠军。' },
  ];

  recoveryTutorials = [
    { title: '运动后的拉伸', description: '运动后拉伸有助于肌肉恢复，减少酸痛。' },
    { title: '泡沫轴的使用', description: '泡沫轴可以帮助放松肌肉，缓解紧张感。' },
  ];

  constructor(private router: Router, private alertController: AlertController) {}

  // ngOnInit 生命周期钩子
  ngOnInit(): void {
    // 如果需要启动自动轮播功能，可以在这里调用
    // 例如：this.startAutoSlide();
  }

  // 显示上一张幻灯片
  prevSlide(): void {
    if (this.currentSlide > 0) {
      this.currentSlide--;
    } else {
      this.currentSlide = this.images.length - 1; // 循环到最后一张
    }
  }

  // 显示下一张幻灯片
  nextSlide(): void {
    if (this.currentSlide < this.images.length - 1) {
      this.currentSlide++;
    } else {
      this.currentSlide = 0; // 循环到第一张
    }
  }

  // 跳转到指定的幻灯片
  goToSlide(index: number): void {
    this.currentSlide = index;
  }

  // 跳转到健身技巧详情页面
  goToFitnessTipDetail(tip: any): void {
    this.router.navigate(['/fitness-tip-detail', { title: tip.title, description: tip.description }]); // 替换为实际的路由路径
  }

  // 跳转到体育新闻详情页面
  goToSportsNewsDetail(news: any): void {
    this.router.navigate(['/sports-news-detail', { title: news.title, description: news.description }]); // 替换为实际的路由路径
  }

  // 跳转到恢复教程详情页面
  goToRecoveryTutorialDetail(tutorial: any): void {
    this.router.navigate(['/recovery-tutorial-detail', { title: tutorial.title, description: tutorial.description }]); // 替换为实际的路由路径
  }
}